@@ -378,6 +378,9 @@ def deployments_download(deployment_name, version_name, output_path, quiet):
 @DEPLOYMENT_MODE_DEPRECATED
 @RETENTION_MODE
 @RETENTION_TIME
+@MAX_QUEUE_SIZE_EXPRESS
+@MAX_QUEUE_SIZE_BATCH
+@VERSION_STATIC_IP
 @VERSION_LABELS
 @VERSION_DESCRIPTION
 @OVERWRITE
@@ -415,6 +418,9 @@ def deployments_deploy(deployment_name, version_name, directory, output_path, ya
     maximum_idle_time: 300
     request_retention_mode: none
     request_retention_time: 604800
+    maximum_queue_size_express: 100
+    maximum_queue_size_batch: 100000
+    static_ip: false
     ```
 
     Those parameters can also be provided as command options. If both a `<yaml_file>` is set and options are given,
@@ -481,9 +487,13 @@ def deployments_deploy(deployment_name, version_name, directory, output_path, ya
         has_changed_fields = False
 
         if not (overwrite and existing_version):
-            version = api.DeploymentVersionCreate(
-                version=version_name, **{k: kwargs[k] for k in DEPLOYMENT_VERSION_FIELDS}
-            )
+            # Only use the fields given in keyword arguments when creating the deployment version
+            version_fields = {}
+            for k in DEPLOYMENT_VERSION_FIELDS:
+                if k in kwargs:
+                    version_fields[k] = kwargs[k]
+
+            version = api.DeploymentVersionCreate(version=version_name, **version_fields)
             client.deployment_versions_create(project_name=project_name, deployment_name=deployment_name, data=version)
         else:
             revisions = client.revisions_list(
