@@ -6,7 +6,7 @@ from ubiops_cli.src.helpers.helpers import get_label_filter
 from ubiops_cli.src.helpers.formatting import print_list, print_item, format_yaml, format_pipeline_requests_reference, \
     format_pipeline_requests_oneline, format_json, format_datetime, parse_datetime
 from ubiops_cli.src.helpers.options import *
-from ubiops_cli.constants import STRUCTURED_TYPE
+from ubiops_cli.constants import STRUCTURED_TYPE, PLAIN_TYPE
 
 
 LIST_ITEMS = ['last_updated', 'name', 'labels']
@@ -333,27 +333,28 @@ def requests_create(pipeline_name, version_name, batch, timeout, deployment_time
     else:
         raise Exception("Missing option <data> or <json_file>")
 
+    method = "pipeline_requests_create"
+    params = {'project_name': project_name, 'pipeline_name': pipeline_name}
+
     if version_name is not None:
-        if batch:
-            response = client.batch_pipeline_version_requests_create(
-                project_name=project_name, pipeline_name=pipeline_name, version=version_name, data=input_data,
-                timeout=timeout
-            )
-        else:
-            response = [client.pipeline_version_requests_create(
-                project_name=project_name, pipeline_name=pipeline_name, version=version_name, data=input_data,
-                pipeline_timeout=timeout, deployment_timeout=deployment_timeout
-            )]
+        method = "pipeline_version_requests_create"
+        params['version'] = version_name
+
+    if batch:
+        params['timeout'] = timeout
     else:
-        if batch:
-            response = client.batch_pipeline_requests_create(
-                project_name=project_name, pipeline_name=pipeline_name, data=input_data, timeout=timeout
-            )
-        else:
-            response = [client.pipeline_requests_create(
-                project_name=project_name, pipeline_name=pipeline_name, data=input_data,
-                pipeline_timeout=timeout, deployment_timeout=deployment_timeout
-            )]
+        params['pipeline_timeout'] = timeout
+        params['deployment_timeout'] = deployment_timeout
+
+    if batch:
+        response = getattr(client, f"batch_{method}")(**params, data=input_data)
+
+    elif pipeline.input_type == PLAIN_TYPE:
+        # We don't support list input for plain type, create the requests one by one
+        response = [getattr(client, method)(**params, data=data) for data in input_data]
+
+    else:
+        response = [getattr(client, method)(**params, data=input_data)]
 
     client.api_client.close()
 
